#コマ
class Panel < Peta::Root
  load_manifest
  belongs_to :author
  has_many :scroll_panels
  has_many :sheet_panels
  has_many :panel_pictures, :dependent => :destroy
  has_many :speech_balloons, :dependent => :destroy
  has_many :ground_pictures, :dependent => :destroy
  has_many :ground_colors, :dependent => :destroy
  accepts_nested_attributes_for :panel_pictures, :allow_destroy => true
  accepts_nested_attributes_for :speech_balloons, :allow_destroy => true
  accepts_nested_attributes_for :ground_pictures, :allow_destroy => true
  accepts_nested_attributes_for :ground_colors, :allow_destroy => true

  validates :width, :presence => true, :numericality => true, :natural_number => true
  validates :height, :presence => true, :numericality => true, :natural_number => true
  validates :border, :presence => true, :numericality => {:greater_than_or_equal_to => 0}
  validates :author_id, :presence => true, :numericality => true, :existence => {:both => false}
  validates :publish, :presence => true, :numericality => true
  
  scope :find_index, -> do
    where(arel_table[:publish].gt 0)
  end
  
  scope :find_private, -> (operators) do 
    where(author_id: operators.author.id)
  end
  
  scope :find_by_author, -> (author_id) do 
    find_index.where(author_id: author_id)
  end
  
  scope :with_scrolls, -> do
    includes(scroll_panels: :scroll)
  end
  
  scope :find_by_scroll, -> (scroll_id) do 
    with_scrolls.find_index.where(Scroll.arel_table[:id].eq scroll_id).references(:scroll)
  end
  
  scope :with_sheets, -> do
    includes(sheet_panels: :sheet)
  end
  
  scope :find_by_sheet, -> (sheet_id) do 
    with_sheets.find_index.where(Sheet.arel_table[:id].eq sheet_id).references(:sheet)
  end
  
  scope :with_speech_balloons, -> do
    includes(:speech_balloons)
  end
  
  scope :find_by_speech_balloon_template, -> (speech_balloon_template_id) do 
    with_speech_balloons.find_index.where(SpeechBalloon.arel_table[:speech_balloon_template_id].eq speech_balloon_template_id).references(:speech_balloon)
  end
  
  def supply_default
    self.border = 2
    self.publish = 0
  end
  
  def overwrite operators
    return false unless operators.author
    self.author_id = operators.author.id
  end
  
  def visible? operators
    case super
    when nil # super return
      return true
    when false
      return false
    else
      return true if self.new_record?
      self.publish?
    end
  end
  
  def usable? operators
    self.visible? operators
  end
  
  def publish?
    self.publish > 0
  end
  
  def style
    {
      'width' => self.width.to_s + 'px', 'height' => self.height.to_s + 'px', 
      'border-style' => 'solid', 'border-width' => self.border.to_s + 'px', 
      'border-color' => 'black', 'background-color' => 'white'
    }
  end
  
  # ground_picture element template 
  def style_wh
    {
      'width' => self.width.to_s + 'px', 'height' => self.height.to_s + 'px'
    }
  end
  
  def self.public_list_where list
    'panels.publish > 0'
  end
  
  def self.show_opt
    r = {
      :author => {}
    }
    self.child_models.each do |child_model|
      r.merge!(child_model.show_opt_for_panel)
    end
    {:include => r}
  end
  
  def scenario
    scenario_elements.map { |e|
      e.scenario
    }.join
  end
  
  def plain_scenario
    scenario_elements.map { |e|
      e.plain_scenario
    }.join
  end
  
  def self.licensed_pictures panels
    r = {}
    panels.each do |panel|
      r.merge!(panel.licensed_pictures)
    end
    r
  end
  
  def licensed_pictures
    r = {}
    self.scenario_elements.each do |elm|
      next unless elm.class.has_picture?
      r[elm.picture_id] = elm.picture unless r[elm.picture_id]
    end
    r
  end
  
end
