module ManifestBase
  class Base
    def self.load manifest, jsons, module_name
      Hash[jsons[module_name].map {|name, json|
        [name, self.new(manifest, name, json, module_name)]
      }]
    end
    
    attr :manifest, :name, :json, :module_name
    
    def initialize manifest, name, json, module_name
      @manifest = manifest
      @name = name
      @json = json
      @module_name = module_name
      self.set_default
      self.init
    end
    
    def set_default
    end
    
    def init
    end
    
    def module_names
      @manifest.module_names + [@module_name, @name]
    end
    
  end
  
  module ModuleMethods
    def require_modules path, names
      names.each do |name|
        require_dependency path + name.to_s
      end
    end
    
    def module_message module_names, my_module_names = []
      (module_names + my_module_names).join(' > ')
    end
    
    def alert_message message, location
      puts 'invalid manifest?'
      p "#{message} for #{message}\n"
#      logger.error "#{message} for #{message}\n"
    end
    
    def alert_undefined_message name, location
      alert_message 'undefined ' + name, location
    end
    
    def load_value _self, json, module_name, klass
      klass.new(_self, json[module_name], module_name)
    end
    
    def load_name_values _self, jsons, module_name, klass
      Hash[jsons[module_name].map {|_name, _json|
        [_name, klass.new(_self, _name, _json, module_name)]
      }]
    end
    
    def load_type_args _self, jsons, module_name, klass
      klass.factory_type_args(_self, jsons[module_name], module_name)
    end
    
    def load_type_name_args _self, jsons, module_name, klass
      Hash[jsons[module_name].map {|_name, _json|
        [_name, klass.factory(_self, _name, _json, module_name)]
      }]
    end
    
    def load_names _self, json, module_name, klass
      json[module_name].map {|_name|
        klass.new(_self, _name, module_name)
      }
    end
    
  end

  extend ModuleMethods

end

