# -*- encoding: utf-8 -*-
#ライセンス
require 'spec_helper'

describe License do
  include ManifestsMacros
  before do
    @model = License
  end
  
  describe 'ペタナイズに於いて' do
    it 'ライセンスグループの内訳。管理者がメンテナンスするアイテムなので、システムリソースにあたる' do
      # テンプレート要件を満たしていないので、テンプレートではない。
      # ライセンスグループに所属しているが、親はバインダーでもなく、ルートでもない。
      # リーフやエレメントとして振る舞うこともできないので、
      # システムリソースとして扱うのが妥当か。 
      expect(@model.ancestors.include?(Peta::SystemResource)).to eq true
    end
    it '親モデルは持たない' do
      expect(@model.my_peta.parent_model_name).to be_blank
    end
    describe 'ブーストに於いて' do
      before do
        @boosts = @model.my_peta.boost
        @boosts_names = ['license_group', 'credit_picture']
      end
      it 'これらのブーストが定義されている' do
        set_boosts? @boosts, @boosts_names
      end
      describe 'ライセンスフラグに於いて' do
        before do
          @mani = @boosts['license_group']
        end
        it 'システム起動前に初期化可能なサポート機能が動作している' do
          expect(@mani.level).to eq 'post'
          expect(@mani.template_name).to eq 'license_group'
          expect(@mani.column_name_for_template_module).to eq 'license_group_module_name'
          expect(@mani.settings_column_name).to eq 'license_group_settings'
          expect(@mani.foreign_key).to eq 'license_group_id'
        end
        it 'システム起動後にしか初期化できないサポート機能が動作している' do
          expect(@mani.item_name_for_extend_model).to eq 'license'
          expect(@mani.setter_method_name).to eq 'license_extend='
          expect(@mani.getter_method_name).to eq 'license_extend'
          expect(@mani.extend_model_class_name).to eq 'License'
          expect(@mani.extend_module_name).to eq 'LicenseModule'
        end
      end
      describe 'クレジットの表示に必要な情報に於いて' do
        before do
          @mani = @boosts['credit_picture']
        end
        it 'システム起動前に初期化可能なサポート機能が動作している' do
          expect(@mani.level).to eq 'read'
          expect(@mani.template_name).to eq 'license_group'
          expect(@mani.column_name_for_template_module).to eq 'license_group_module_name'
          expect(@mani.settings_column_name).to eq 'credit_picture_settings'
          expect(@mani.foreign_key).to eq 'license_group_id'
        end
        it 'システム起動後にしか初期化できないサポート機能が動作している' do
          expect(@mani.item_name_for_extend_model).to eq 'credit_picture'
          expect(@mani.setter_method_name).to eq 'credit_picture_extend='
          expect(@mani.getter_method_name).to eq 'credit_picture_extend'
          expect(@mani.extend_model_class_name).to eq 'CreditPicture'
          expect(@mani.extend_module_name).to eq 'CreditPictureModule'
        end
      end
    end
    
  end
  
  describe 'コントローラに於いて' do
    before do
      @controller = @model.my_controller
    end
    it 'ライセンスのためのコントローラである' do
      expect(@model.item_name).to eq 'license'
    end
    describe 'actionに於いて' do
      before do
        @actions = @controller.actions
        @actions_names = ['index', 'by_license_group', 'by_system_picture', 'show', 
          'count', 'count_by_license_group', 'count_by_system_picture', 
          'new', 'edit', 'create', 'update', 'destroy']
      end
      it 'これらのアクションが定義されている' do
        set_actions? @actions, @actions_names
      end
      describe 'baseに於いて' do
      end
      describe 'indexに於いて' do
        before do
          @action = @actions['index']
        end
        it 'listタイプのアクションである' do
          expect(@action.type).to eq 'list'
        end
        it 'マニフェストから設定を取り出している' do
          # ライセンスの公開リストを返すように定義している
          set_list_action? @action, 'license', 'public'
        end
      end
      describe 'by_license_groupに於いて' do
        before do
          @action = @actions['by_license_group']
        end
        it 'listタイプのアクションである' do
          expect(@action.type).to eq 'list'
        end
        it 'マニフェストから設定を取り出している' do
          # ライセンスのライセンスグループ フィルタリストを返すように定義している
          set_list_action? @action, 'license', 'by_license_group'
        end
      end
      describe 'by_system_pictureに於いて' do
        before do
          @action = @actions['by_system_picture']
        end
        it 'listタイプのアクションである' do
          expect(@action.type).to eq 'list'
        end
        it 'マニフェストから設定を取り出している' do
          #ライセンスのシステム画像フィルタリストを返すように定義している
          set_list_action? @action, 'license', 'by_system_picture'
        end
      end
      describe 'countに於いて' do
        before do
          @action = @actions['count']
        end
        it 'countタイプのアクションである' do
          expect(@action.type).to eq 'count'
        end
        it 'マニフェストから設定を取り出している' do
          #ライセンスの公開リストのカウントを返すように定義している
          set_list_action? @action, 'license', 'public'
        end
      end
      describe 'showに於いて' do
        before do
          @action = @actions['show']
        end
        it 'showタイプのアクションである' do
          expect(@action.type).to eq 'show'
        end
      end
      describe 'count_by_license_groupに於いて' do
        before do
          @action = @actions['count_by_license_group']
        end
        it 'countタイプのアクションである' do
          expect(@action.type).to eq 'count'
        end
        it 'マニフェストから設定を取り出している' do
          # ライセンスのライセンスグループ フィルタリストのカウントを返すように定義している
          set_list_action? @action, 'license', 'by_license_group'
        end
      end
      describe 'count_by_system_pictureに於いて' do
        before do
          @action = @actions['count_by_system_picture']
        end
        it 'countタイプのアクションである' do
          expect(@action.type).to eq 'count'
        end
        it 'マニフェストから設定を取り出している' do
          # ライセンスのシステム画像フィルタリストのカウントを返すように定義している
          set_list_action? @action, 'license', 'by_system_picture'
        end
      end
      describe 'newに於いて' do
        before do
          @action = @actions['new']
        end
        it 'newタイプのアクションである' do
          expect(@action.type).to eq 'new'
        end
        it 'type' do
          expect(@action.item_name).to eq 'license'
        end
      end
      describe 'editに於いて' do
        before do
          @action = @actions['edit']
        end
        it 'editタイプのアクションである' do
          expect(@action.type).to eq 'edit'
        end
        it 'type' do
          expect(@action.item_name).to eq 'license'
        end
      end
      describe 'createに於いて' do
        before do
          @action = @actions['create']
        end
        it 'createタイプのアクションである' do
          expect(@action.type).to eq 'create'
        end
        it 'type' do
          expect(@action.item_name).to eq 'license'
        end
      end
      describe 'updateに於いて' do
        before do
          @action = @actions['update']
        end
        it 'updateタイプのアクションである' do
          expect(@action.type).to eq 'update'
        end
        it 'type' do
          expect(@action.item_name).to eq 'license'
        end
      end
      describe 'destroyに於いて' do
        before do
          @action = @actions['destroy']
        end
        it 'destroyタイプのアクションである' do
          expect(@action.type).to eq 'destroy'
        end
        it 'type' do
          expect(@action.item_name).to eq 'license'
        end
      end
    end
    
  end
  
  describe 'モデルに於いて' do
    before do
      @my_manifest = @model.my_manifest
    end
    it 'サポート機能が動作している' do
      expect(@my_manifest.model_name).to eq 'license'
      expect(@my_manifest.classify).to eq @model
      expect(@my_manifest.table_name).to eq 'licenses'
    end
    
    describe 'associationsに於いて' do
      describe 'belongs_toに於いて' do
        before do
          @belongs_to = @my_manifest.associations.belongs_to
          @names = ['license_group', 'system_picture']
        end
        it 'これらのモデルに所属している' do
          set_associations? @belongs_to, @names
        end
        describe 'license_groupに於いて' do
          before do
            @mani = @belongs_to['license_group']
          end
          it 'マニフェストから設定を取り出している' do
            # モデル名と外部キーが定義あるいはデフォルト値補充されている
            expect(@mani.model_name).to eq 'license_group'
            expect(@mani.id_column).to eq 'license_group_id'
          end
          it 'サポート機能が動作している' do
            # モデルを再現できている
            expect(@mani.model).to eq LicenseGroup
          end
        end
        describe 'system_pictureに於いて' do
          before do
            @mani = @belongs_to['system_picture']
          end
          it 'マニフェストから設定を取り出している' do
            # モデル名と外部キーが定義あるいはデフォルト値補充されている
            expect(@mani.model_name).to eq 'system_picture'
            expect(@mani.id_column).to eq 'system_picture_id'
          end
          it 'サポート機能が動作している' do
            # モデルを再現できている
            expect(@mani.model).to eq SystemPicture
          end
        end
      end
      describe 'has_manyに於いて' do
        before do
          @has_many = @model.my_manifest.associations.has_many
          @names = ['resource_pictures']
        end
        it 'これらのモデルを所持している' do
          set_associations? @has_many, @names
        end
        describe 'resource_picturesに於いて' do
          before do
            @mani = @has_many['resource_pictures']
          end
          it 'マニフェストから設定を取り出している' do
            # モデル名, 外部キーと中間モデルが定義あるいはデフォルト値補充されている
            expect(@mani.model_name).to eq 'resource_picture'
            expect(@mani.foreign_key).to eq 'license_id'
            expect(@mani.through).to be nil
          end
          it 'サポート機能が動作している' do
            # モデルを再現できている, 中間モデルフラグ
            expect(@mani.through?).to be false
            expect(@mani.model).to eq ResourcePicture
          end
        end
      end
    end
    
    describe 'attributesに於いて' do
      before do
        @attributes = @model.my_manifest.attributes
      end
      it 'これらのカラムを定義している' do
        set_attributes? @attributes, 
          ['id', 'license_group_id', 'license_group_module_name', 
          'name', 'caption', 'system_picture_id', 'url', 
          'license_group_settings', 'credit_picture_settings', 
          'created_at', 'updated_at']
      end
      describe 'license_group_idに於いて' do
        before do
          @attribute = @attributes['license_group_id']
        end
        it 'numberタイプである' do
          expect(@attribute.type).to eq 'number'
        end
      end
      describe 'license_group_module_nameに於いて' do
        before do
          @attribute = @attributes['license_group_module_name']
        end
        it 'textタイプである' do
          expect(@attribute.type).to eq 'text'
        end
      end
      describe 'nameに於いて' do
        before do
          @attribute = @attributes['name']
        end
        it 'textタイプである' do
          expect(@attribute.type).to eq 'text'
        end
      end
      describe 'captionに於いて' do
        before do
          @attribute = @attributes['caption']
        end
        it 'textタイプである' do
          expect(@attribute.type).to eq 'text'
        end
      end
      describe 'system_picture_idに於いて' do
        before do
          @attribute = @attributes['system_picture_id']
        end
        it 'numberタイプである' do
          expect(@attribute.type).to eq 'number'
        end
      end
      describe 'urlに於いて' do
        before do
          @attribute = @attributes['url']
        end
        it 'textタイプである' do
          expect(@attribute.type).to eq 'text'
        end
      end
      describe 'license_group_settingsに於いて' do
        before do
          @attribute = @attributes['license_group_settings']
        end
        it 'textタイプである' do
          expect(@attribute.type).to eq 'text'
        end
      end
      describe 'credit_picture_settingsに於いて' do
        before do
          @attribute = @attributes['credit_picture_settings']
        end
        it 'textタイプである' do
          expect(@attribute.type).to eq 'text'
        end
      end
    end
    
  end
  
end
